void remsBIL(){}
void bit_accuracy(){}
void is_bigint(){}
void divsBIL(){}
void copy_bin(){}
void pari_free(){}
void pari_malloc(){}
void shiftaddress(){}
void shiftaddress_canon(){}
void powuu(){}
void gerepilemanysp(){}
void ceilr(){}
void roundr(){}
void pari_err(){}
void pari_warn(){}
void quadratic_prec_mask(){}
